%define pkgver %(echo %{version}|sed 's,[.],,g')
%define bookver 211

Name:           stockfish
Version:        13
Release:        %mkrel 2
Summary:        A chess engine
License:        GPLv3
Group:          Games/Boards
URL:            https://stockfishchess.org/
# download from https://stockfishchess.org/download/
Source0:        https://github.com/official-stockfish/Stockfish/archive/sf_%{version}.zip
Source1:        sf-%{bookver}-book.zip
Source2:        https://tests.stockfishchess.org/api/nn/nn-62ef826d1a6d.nnue
Patch0:         stockfish-no-m32-m64.patch
BuildRequires:  dos2unix
%ifarch %{arm}
BuildRequires:  libatomic-devel
%endif

%description
Stockfish is a free UCI chess engine derived from Glaurung 2.1. It is not a
complete chess program, but requires some UCI compatible GUI (like XBoard
with PolyGlot, eboard, Arena, Sigma Chess, Shredder, Chess Partner or Fritz)
in order to be used comfortably. Read the documentation for your GUI of choice
for information about how to use Stockfish with your GUI.


%prep
%setup -q -n Stockfish-sf_%{version} -a 1
%autopatch -p1

# remove trash
rm -fr ../__MACOSX

# fix new-lines
dos2unix README.md

# Default net: nn-62ef826d1a6d.nnue
cp %{SOURCE2} src/

%build
export CFLAGS="%{optflags} -fPIC"
export CCFLAGS="%{optflags} -fPIC"
export CXXFLAGS="%{optflags} -fPIC"
export LDFLAGS="%{ldflags}"

%ifarch x86_64
make build -C src ARCH=x86-64
%endif
%ifarch %{ix86}
make build -C src ARCH=x86-32
%endif
%ifarch %{arm}
make build -C src ARCH=armv7
%endif
%ifarch aarch64
make build -C src ARCH=general-64
%endif

%install
# the binary
install -D -m0755 src/%{name} %{buildroot}%{_gamesbindir}/%{name}

mkdir -p %{buildroot}%{_gamesdatadir}/%{name}

# the opening book
install -m0644 sf-%{bookver}-book/Book.bin %{buildroot}%{_gamesdatadir}/%{name}

%files
%doc README.md
%{_gamesbindir}/%{name}
%{_gamesdatadir}/*


%changelog
* Fri Mar 18 2022 umeabot <umeabot> 13-2.mga9
+ Revision: 1797540
- Mageia 9 Mass Rebuild

* Tue Apr 27 2021 daviddavid <daviddavid> 13-1.1.mga9
+ Revision: 1720082
- new version: 13

* Fri Feb 14 2020 umeabot <umeabot> 10-2.mga8
+ Revision: 1521775
- Mageia 8 Mass Rebuild

* Tue Jan 01 2019 kekepower <kekepower> 10-1.mga7
+ Revision: 1348141
- Update to version 10

* Sun Sep 23 2018 umeabot <umeabot> 9-3.mga7
+ Revision: 1301205
- Mageia 7 Mass Rebuild

* Mon Jul 09 2018 wally <wally> 9-2.mga7
+ Revision: 1242719
- add patch to not add -m32/-m64 to CXXFLAGS
- use mga compiler flags
- add aarch64 build support

* Mon Apr 23 2018 kekepower <kekepower> 9-1.mga7
+ Revision: 1221913
- Update to version 9
- Enable build on ARM
- Tidy up the spec file

* Fri Jan 29 2016 umeabot <umeabot> 2.3.1-4.mga6
+ Revision: 928737
- Mageia 6 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 2.3.1-3.mga5
+ Revision: 519214
- Mageia 4 Mass Rebuild

* Mon Jan 14 2013 umeabot <umeabot> 2.3.1-2.mga3
+ Revision: 383486
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 02 2012 kamil <kamil> 2.3.1-1.mga3
+ Revision: 324781
- new version 2.3.1
- rediff djust-opening-book.patch

* Wed Jul 25 2012 kamil <kamil> 2.2.2-1.mga3
+ Revision: 274391
- imported package stockfish

